@@ -1,15 +1,14 @@
 /*
- *  SPDX-FileCopyrightText: 2013-2016 Andreas Cord-Landwehr <cordlandwehr@kde.org>
- *
- *  SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
- */
+    SPDX-FileCopyrightText: 2013-2016 Andreas Cord-Landwehr <cordlandwehr@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+*/
 
 #include "learner.h"
 #include "learner_p.h"
 #include "liblearner_debug.h"
 #include <QDir>
 #include <QFileInfo>
-#include <QHash>
 #include <QPixmap>
 
 using namespace LearnerProfile;
